@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -95,6 +95,21 @@ ActivityModule::ActivityModule(ActivityHandler *activityHandler,
     m_maxDateEdit->calendarWidget()->setGridVisible(true);
     m_maxDateEdit->setDisplayFormat("dd MMMM");
 
+    m_wdayMonCheckbox = new QCheckBox(tr("Mon", "Monday, shortened if possible"),
+                                      this);
+    m_wdayTueCheckbox = new QCheckBox(tr("Tue", "Tuesday, shortened if possible"),
+                                      this);
+    m_wdayWedCheckbox = new QCheckBox(tr("Wed", "Wednesday, shortened if possible"),
+                                      this);
+    m_wdayThuCheckbox = new QCheckBox(tr("Thu", "Thursday, shortened if possible"),
+                                      this);
+    m_wdayFriCheckbox = new QCheckBox(tr("Fri", "Friday, shortened if possible"),
+                                      this);
+    m_wdaySatCheckbox = new QCheckBox(tr("Sat", "Saturday, shortened if possible"),
+                                      this);
+    m_wdaySunCheckbox = new QCheckBox(tr("Sun", "Sunday, shortened if possible"),
+                                      this);
+
     m_minDurationSpinbox = new QSpinBox(this);
     m_minDurationSpinbox->setRange(1, 1440); // Up to 1440 min, 24h
     m_maxDurationSpinbox = new QSpinBox(this);
@@ -190,6 +205,15 @@ ActivityModule::ActivityModule(ActivityHandler *activityHandler,
     m_dateLayout->addSpacing(8);
     m_dateLayout->addWidget(m_maxDateEdit);
 
+    m_weekdaysLayout = new QHBoxLayout();
+    m_weekdaysLayout->addWidget(m_wdayMonCheckbox);
+    m_weekdaysLayout->addWidget(m_wdayTueCheckbox);
+    m_weekdaysLayout->addWidget(m_wdayWedCheckbox);
+    m_weekdaysLayout->addWidget(m_wdayThuCheckbox);
+    m_weekdaysLayout->addWidget(m_wdayFriCheckbox);
+    m_weekdaysLayout->addWidget(m_wdaySatCheckbox);
+    m_weekdaysLayout->addWidget(m_wdaySunCheckbox);
+
     m_durationLayout = new QHBoxLayout();
     m_durationLayout->addWidget(m_minDurationSpinbox);
     m_durationLayout->addSpacing(8);
@@ -220,6 +244,7 @@ ActivityModule::ActivityModule(ActivityHandler *activityHandler,
     m_formLayout->addRow(tr("Probability"),           m_probabilitySpinbox);
     m_formLayout->addRow(tr("Time Range"),            m_timeLayout);
     m_formLayout->addRow(tr("Date Range"),            m_dateLayout);
+    m_formLayout->addRow(tr("Days Of The Week"),      m_weekdaysLayout);
     m_formLayout->addRow(tr("Duration"),              m_durationLayout);
     m_formLayout->addRow(tr("Set Status Type"),       m_statusTypeCombobox);
     m_formLayout->addRow(tr("Status Messages"),       m_statusMessagesListWidget);
@@ -273,7 +298,7 @@ void ActivityModule::loadActivities()
 {
     const QVariantList activityDataList = m_dataFile->loadData();
 
-    foreach (const QVariant listItem, activityDataList)
+    for (const QVariant listItem : activityDataList)
     {
         const QVariantMap map = listItem.toMap();
         QListWidgetItem *item = new QListWidgetItem();
@@ -286,20 +311,20 @@ void ActivityModule::loadActivities()
         item->setData(Qt::UserRole + 4,  map.value("maxTime"));
         item->setData(Qt::UserRole + 5,  map.value("minDate"));
         item->setData(Qt::UserRole + 6,  map.value("maxDate"));
-        item->setData(Qt::UserRole + 7,  map.value("minDuration"));
-        item->setData(Qt::UserRole + 8,  map.value("maxDuration"));
-        item->setData(Qt::UserRole + 9,  map.value("statusType"));
-        item->setData(Qt::UserRole + 10, map.value("statusMessages"));
-        item->setData(Qt::UserRole + 11, map.value("availability"));
-        item->setData(Qt::UserRole + 12, map.value("minReaction"));
-        item->setData(Qt::UserRole + 13, map.value("maxReaction"));
-        item->setData(Qt::UserRole + 14, map.value("descriptions"));
-        item->setData(Qt::UserRole + 15, map.value("msgBefore"));
-        item->setData(Qt::UserRole + 16, map.value("msgAfter"));
-        item->setData(Qt::UserRole + 17, map.value("msgToRooms"));
-        item->setData(Qt::UserRole + 18, map.value("msgToChats"));
-        item->setData(Qt::UserRole + 19, map.value("specificJids"));
-
+        item->setData(Qt::UserRole + 7,  map.value("daysOfWeek", 127));
+        item->setData(Qt::UserRole + 8,  map.value("minDuration"));
+        item->setData(Qt::UserRole + 9,  map.value("maxDuration"));
+        item->setData(Qt::UserRole + 10, map.value("statusType"));
+        item->setData(Qt::UserRole + 11, map.value("statusMessages"));
+        item->setData(Qt::UserRole + 12, map.value("availability"));
+        item->setData(Qt::UserRole + 13, map.value("minReaction"));
+        item->setData(Qt::UserRole + 14, map.value("maxReaction"));
+        item->setData(Qt::UserRole + 15, map.value("descriptions"));
+        item->setData(Qt::UserRole + 16, map.value("msgBefore"));
+        item->setData(Qt::UserRole + 17, map.value("msgAfter"));
+        item->setData(Qt::UserRole + 18, map.value("msgToRooms"));
+        item->setData(Qt::UserRole + 19, map.value("msgToChats"));
+        item->setData(Qt::UserRole + 20, map.value("specificJids"));
 
         m_activityListWidget->addItem(item);
     }
@@ -352,32 +377,35 @@ void ActivityModule::addActivity()
     item->setData(Qt::UserRole + 5, QDate(2000,  1,  1));
     item->setData(Qt::UserRole + 6, QDate(2000, 12, 31));
 
+    // Days of the week
+    item->setData(Qt::UserRole + 7, 127); // All selected (7 lower bits on)
+
     // Duration range
-    item->setData(Qt::UserRole + 7, 1);
-    item->setData(Qt::UserRole + 8, 10);
+    item->setData(Qt::UserRole + 8, 1);
+    item->setData(Qt::UserRole + 9, 10);
 
     // Status type
-    item->setData(Qt::UserRole + 9, 0);
+    item->setData(Qt::UserRole + 10, 0);
 
-    // Nothing to set here for the status messages list (UR + 10)
+    // Nothing to set here for the status messages list (UR + 11)
 
     // Availability %
-    item->setData(Qt::UserRole + 11, 50);
+    item->setData(Qt::UserRole + 12, 50);
 
     // Reaction time range
-    item->setData(Qt::UserRole + 12, 1);
-    item->setData(Qt::UserRole + 13, 10);
+    item->setData(Qt::UserRole + 13, 1);
+    item->setData(Qt::UserRole + 14, 10);
 
-    // Nothing to set here for the lists (UR + 14, 15, 16)
+    // Nothing to set here for the lists (UR + 15, 16, 17)
 
     // Send messages to all/several/few room
-    item->setData(Qt::UserRole + 17, 0);
+    item->setData(Qt::UserRole + 18, 0);
 
     // Messages also to active private chats
-    item->setData(Qt::UserRole + 18, true);
+    item->setData(Qt::UserRole + 19, true);
 
     // Specific recipient JIDs
-    item->setData(Qt::UserRole + 19, "");
+    item->setData(Qt::UserRole + 20, QVariant());
 
     m_activityListWidget->addItem(item);
 
@@ -426,30 +454,43 @@ void ActivityModule::onActivitySelected(int row)
     m_minDateEdit->setDate(item->data(Qt::UserRole + 5).toDate());
     m_maxDateEdit->setDate(item->data(Qt::UserRole + 6).toDate());
 
-    m_minDurationSpinbox->setValue(item->data(Qt::UserRole + 7).toInt());
-    m_maxDurationSpinbox->setValue(item->data(Qt::UserRole + 8).toInt());
+    const int weekdays = item->data(Qt::UserRole + 7).toInt();
+    m_wdayMonCheckbox->setChecked(weekdays & 1);
+    m_wdayTueCheckbox->setChecked(weekdays & 2);
+    m_wdayWedCheckbox->setChecked(weekdays & 4);
+    m_wdayThuCheckbox->setChecked(weekdays & 8);
+    m_wdayFriCheckbox->setChecked(weekdays & 16);
+    m_wdaySatCheckbox->setChecked(weekdays & 32);
+    m_wdaySunCheckbox->setChecked(weekdays & 64);
 
-    m_statusTypeCombobox->setCurrentIndex(item->data(Qt::UserRole + 9).toInt());
+    m_minDurationSpinbox->setValue(item->data(Qt::UserRole + 8).toInt());
+    m_maxDurationSpinbox->setValue(item->data(Qt::UserRole + 9).toInt());
+
+    m_statusTypeCombobox->setCurrentIndex(item->data(Qt::UserRole + 10).toInt());
     m_statusMessagesListWidget->clearList();
-    m_statusMessagesListWidget->addStringsToList(item->data(Qt::UserRole + 10).toStringList());
+    m_statusMessagesListWidget->addStringsToList(item->data(Qt::UserRole + 11)
+                                                      .toStringList());
 
-    m_availabilitySpinbox->setValue(item->data(Qt::UserRole + 11).toInt());
+    m_availabilitySpinbox->setValue(item->data(Qt::UserRole + 12).toInt());
 
-    m_minReactionSpinbox->setValue(item->data(Qt::UserRole + 12).toInt());
-    m_maxReactionSpinbox->setValue(item->data(Qt::UserRole + 13).toInt());
+    m_minReactionSpinbox->setValue(item->data(Qt::UserRole + 13).toInt());
+    m_maxReactionSpinbox->setValue(item->data(Qt::UserRole + 14).toInt());
 
     m_descriptionListWidget->clearList();
-    m_descriptionListWidget->addStringsToList(item->data(Qt::UserRole + 14).toStringList());
+    m_descriptionListWidget->addStringsToList(item->data(Qt::UserRole + 15)
+                                                   .toStringList());
 
     m_msgBeforeListWidget->clearList();
-    m_msgBeforeListWidget->addStringsToList(item->data(Qt::UserRole + 15).toStringList());
+    m_msgBeforeListWidget->addStringsToList(item->data(Qt::UserRole + 16)
+                                                 .toStringList());
 
     m_msgAfterListWidget->clearList();
-    m_msgAfterListWidget->addStringsToList(item->data(Qt::UserRole + 16).toStringList());
+    m_msgAfterListWidget->addStringsToList(item->data(Qt::UserRole + 17)
+                                                .toStringList());
 
-    m_msgToRoomsCombobox->setCurrentIndex(item->data(Qt::UserRole + 17).toInt());
-    m_msgToActiveChatsCheckbox->setChecked(item->data(Qt::UserRole + 18).toBool());
-    m_specificJidsLineEdit->setText(item->data(Qt::UserRole + 19).toString());
+    m_msgToRoomsCombobox->setCurrentIndex(item->data(Qt::UserRole + 18).toInt());
+    m_msgToActiveChatsCheckbox->setChecked(item->data(Qt::UserRole + 19).toBool());
+    m_specificJidsLineEdit->setText(item->data(Qt::UserRole + 20).toString());
 
 
     m_removeActivityButton->setEnabled(true);
@@ -499,25 +540,34 @@ void ActivityModule::saveActivity()
     item->setData(Qt::UserRole + 5, m_minDateEdit->date());
     item->setData(Qt::UserRole + 6, m_maxDateEdit->date());
 
-    item->setData(Qt::UserRole + 7, m_minDurationSpinbox->value());
-    item->setData(Qt::UserRole + 8, m_maxDurationSpinbox->value());
+    int weekdays = 0;
+    weekdays += m_wdayMonCheckbox->isChecked() ? 1  : 0;
+    weekdays += m_wdayTueCheckbox->isChecked() ? 2  : 0;
+    weekdays += m_wdayWedCheckbox->isChecked() ? 4  : 0;
+    weekdays += m_wdayThuCheckbox->isChecked() ? 8  : 0;
+    weekdays += m_wdayFriCheckbox->isChecked() ? 16 : 0;
+    weekdays += m_wdaySatCheckbox->isChecked() ? 32 : 0;
+    weekdays += m_wdaySunCheckbox->isChecked() ? 64 : 0;
+    item->setData(Qt::UserRole + 7, weekdays);
 
-    item->setData(Qt::UserRole + 9, m_statusTypeCombobox->currentIndex());
-    item->setData(Qt::UserRole + 10, m_statusMessagesListWidget->getStringsFromList());
+    item->setData(Qt::UserRole + 8, m_minDurationSpinbox->value());
+    item->setData(Qt::UserRole + 9, m_maxDurationSpinbox->value());
 
-    item->setData(Qt::UserRole + 11, m_availabilitySpinbox->value());
+    item->setData(Qt::UserRole + 10, m_statusTypeCombobox->currentIndex());
+    item->setData(Qt::UserRole + 11, m_statusMessagesListWidget->getStringsFromList());
 
-    item->setData(Qt::UserRole + 12, m_minReactionSpinbox->value());
-    item->setData(Qt::UserRole + 13, m_maxReactionSpinbox->value());
+    item->setData(Qt::UserRole + 12, m_availabilitySpinbox->value());
 
-    item->setData(Qt::UserRole + 14, m_descriptionListWidget->getStringsFromList());
-    item->setData(Qt::UserRole + 15, m_msgBeforeListWidget->getStringsFromList());
-    item->setData(Qt::UserRole + 16, m_msgAfterListWidget->getStringsFromList());
+    item->setData(Qt::UserRole + 13, m_minReactionSpinbox->value());
+    item->setData(Qt::UserRole + 14, m_maxReactionSpinbox->value());
 
-    item->setData(Qt::UserRole + 17, m_msgToRoomsCombobox->currentIndex());
-    item->setData(Qt::UserRole + 18, m_msgToActiveChatsCheckbox->isChecked());
-    item->setData(Qt::UserRole + 19, m_specificJidsLineEdit->text());
+    item->setData(Qt::UserRole + 15, m_descriptionListWidget->getStringsFromList());
+    item->setData(Qt::UserRole + 16, m_msgBeforeListWidget->getStringsFromList());
+    item->setData(Qt::UserRole + 17, m_msgAfterListWidget->getStringsFromList());
 
+    item->setData(Qt::UserRole + 18, m_msgToRoomsCombobox->currentIndex());
+    item->setData(Qt::UserRole + 19, m_msgToActiveChatsCheckbox->isChecked());
+    item->setData(Qt::UserRole + 20, m_specificJidsLineEdit->text());
 
 
     m_activityListWidget->setFocus();
@@ -543,19 +593,20 @@ void ActivityModule::syncActivities()
         activityMap.insert("maxTime",        item->data(Qt::UserRole + 4));
         activityMap.insert("minDate",        item->data(Qt::UserRole + 5));
         activityMap.insert("maxDate",        item->data(Qt::UserRole + 6));
-        activityMap.insert("minDuration",    item->data(Qt::UserRole + 7));
-        activityMap.insert("maxDuration",    item->data(Qt::UserRole + 8));
-        activityMap.insert("statusType",     item->data(Qt::UserRole + 9));
-        activityMap.insert("statusMessages", item->data(Qt::UserRole + 10));
-        activityMap.insert("availability",   item->data(Qt::UserRole + 11));
-        activityMap.insert("minReaction",    item->data(Qt::UserRole + 12));
-        activityMap.insert("maxReaction",    item->data(Qt::UserRole + 13));
-        activityMap.insert("descriptions",   item->data(Qt::UserRole + 14));
-        activityMap.insert("msgBefore",      item->data(Qt::UserRole + 15));
-        activityMap.insert("msgAfter",       item->data(Qt::UserRole + 16));
-        activityMap.insert("msgToRooms",     item->data(Qt::UserRole + 17));
-        activityMap.insert("msgToChats",     item->data(Qt::UserRole + 18));
-        activityMap.insert("specificJids",   item->data(Qt::UserRole + 19));
+        activityMap.insert("daysOfWeek",     item->data(Qt::UserRole + 7));
+        activityMap.insert("minDuration",    item->data(Qt::UserRole + 8));
+        activityMap.insert("maxDuration",    item->data(Qt::UserRole + 9));
+        activityMap.insert("statusType",     item->data(Qt::UserRole + 10));
+        activityMap.insert("statusMessages", item->data(Qt::UserRole + 11));
+        activityMap.insert("availability",   item->data(Qt::UserRole + 12));
+        activityMap.insert("minReaction",    item->data(Qt::UserRole + 13));
+        activityMap.insert("maxReaction",    item->data(Qt::UserRole + 14));
+        activityMap.insert("descriptions",   item->data(Qt::UserRole + 15));
+        activityMap.insert("msgBefore",      item->data(Qt::UserRole + 16));
+        activityMap.insert("msgAfter",       item->data(Qt::UserRole + 17));
+        activityMap.insert("msgToRooms",     item->data(Qt::UserRole + 18));
+        activityMap.insert("msgToChats",     item->data(Qt::UserRole + 19));
+        activityMap.insert("specificJids",   item->data(Qt::UserRole + 20));
 
 
         // Don't save activities without a name
