@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -106,6 +106,15 @@ private:
     QDateEdit *m_minDateEdit;
     QDateEdit *m_maxDateEdit;
 
+    QHBoxLayout *m_weekdaysLayout;
+    QCheckBox *m_wdayMonCheckbox;
+    QCheckBox *m_wdayTueCheckbox;
+    QCheckBox *m_wdayWedCheckbox;
+    QCheckBox *m_wdayThuCheckbox;
+    QCheckBox *m_wdayFriCheckbox;
+    QCheckBox *m_wdaySatCheckbox;
+    QCheckBox *m_wdaySunCheckbox;
+
     QHBoxLayout *m_durationLayout;
     QSpinBox *m_minDurationSpinbox;
     QSpinBox *m_maxDurationSpinbox;
