@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -204,8 +204,8 @@ void ChatWidget::appendMessage(QXmppMessage message)
     if (message.stamp().isValid())
     {
         logMessage.append(QStringLiteral("{")
-                          + message.stamp().toLocalTime()
-                                           .toString(Qt::SystemLocaleShortDate)
+                          + QLocale::system().toString(message.stamp().toLocalTime(),
+                                                       QLocale::ShortFormat)
                           + QStringLiteral("} "));
     }
 
@@ -459,6 +459,15 @@ void ChatWidget::showEvent(QShowEvent *event)
     m_unreadCount = 0;
     emit messagesRead(m_chatTitle, unreadBefore);
 
+    // Sometimes, on show, scrollbar sliders get set to slightly less than the maximum,
+    // which makes them stay there after more messages appear; work around it
+    const int scrollNow = m_chatBrowser->verticalScrollBar()->value();
+    const int scrollMax = m_chatBrowser->verticalScrollBar()->maximum();
+    if (scrollNow < scrollMax && scrollNow >= (scrollMax - 4))
+    {
+        m_chatBrowser->verticalScrollBar()->setValue(scrollMax);
+    }
+
     event->accept();
 }
 
