@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -264,17 +264,17 @@ QVariantMap CommandHandler::parseCommand(QString commandString, int userAccess,
     }
     else if (command == QStringLiteral("date"))
     {
-        commandReply = QDateTime::currentDateTime()
-                                 .toLocalTime()
-                                 .toString(Qt::SystemLocaleLongDate);
+        commandReply = QLocale::system().toString(QDateTime::currentDateTime()
+                                                  .toLocalTime(),
+                                                  QLocale::LongFormat);
 
         const qint64 uptime = m_globalObject->getConnectionStartTime()
                                              .secsTo(QDateTime::currentDateTimeUtc());
 
         commandReply.append("\nUp since: " /// TMP?
-                            + m_globalObject->getConnectionStartTime()
-                                             .toLocalTime()
-                                             .toString(Qt::SystemLocaleLongDate)
+                            + QLocale::system().toString(m_globalObject->getConnectionStartTime()
+                                                         .toLocalTime(),
+                                                         QLocale::LongFormat)
                             + " ~ "
                             + Helpers::durationString(uptime));
     }
@@ -390,6 +390,7 @@ QVariantMap CommandHandler::parseCommand(QString commandString, int userAccess,
 
                     QString commandLine = programToRun.value("commandLine")
                                                       .toString().trimmed();
+
                     QProcess programProcess;
                     if (programToRun.value("detached").toInt() == 1) // Detached
                     {
@@ -413,7 +414,8 @@ QVariantMap CommandHandler::parseCommand(QString commandString, int userAccess,
                         if (programProcess.waitForStarted())
                         {
                             qDebug() << "Started process:"
-                                     << programProcess.program();
+                                     << programProcess.program()
+                                     << programProcess.arguments();
 
                             if (programProcess.waitForFinished(10000)) // Up to 10 secs; FIXME
                             {
