@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -297,7 +297,7 @@ void CommandModule::loadCommands()
 {
     const QVariantList commandDataList = m_dataFile->loadData();
 
-    foreach (const QVariant listItem, commandDataList)
+    for (const QVariant listItem : commandDataList)
     {
         const QVariantMap map = listItem.toMap();
         QListWidgetItem *item = new QListWidgetItem();
