@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -275,9 +275,9 @@ void ConfigDialog::saveSettings()
                       m_adminJidListWidget->getStringsFromList());
     settings.setValue("commandPrefix",
                       m_commandPrefixLineEdit->text().trimmed());
-    settings.setValue("keepaliveInterval",
+    settings.setValue("keepAliveInterval",
                       m_keepAliveIntervalSpinbox->value());
-    settings.setValue("keepaliveTimeout",
+    settings.setValue("keepAliveTimeout",
                       m_keepAliveTimeoutSpinbox->value());
     m_globalObject->syncGeneralSettings(m_adminJidListWidget->getStringsFromList(),
                                         m_commandPrefixLineEdit->text().trimmed(),
