@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 
 ConnectionDialog::ConnectionDialog(QString jid, QString password,
                                    bool autoconnect, QString resource,
-                                   int priority,
+                                   int priority, bool ignoreSslErrors,
                                    QWidget *parent) : QWidget(parent)
 {
     this->setWindowTitle(tr("Connection Settings") + " - AkariXB");
@@ -59,6 +59,13 @@ ConnectionDialog::ConnectionDialog(QString jid, QString password,
     m_prioritySpinbox->setRange(-1, 100);
     m_prioritySpinbox->setValue(priority);
 
+    m_ignoreSslCheckbox = new QCheckBox(tr("Use carefully.") + "\n"
+                                        + tr("This allows connecting to "
+                                             "servers with bad "
+                                             "security certificates."),
+                                        this);
+    m_ignoreSslCheckbox->setChecked(ignoreSslErrors);
+
 
     m_connectButton = new QPushButton(QIcon::fromTheme("network-connect",
                                                        QIcon(":/images/button-online.png")),
@@ -91,6 +98,7 @@ ConnectionDialog::ConnectionDialog(QString jid, QString password,
     m_topLayout->addRow(tr("Connect Automatically"),    m_autoconnectCheckbox);
     m_topLayout->addRow(tr("Resource"),                 m_resourceLineEdit);
     m_topLayout->addRow(tr("Priority"),                 m_prioritySpinbox);
+    m_topLayout->addRow(tr("Ignore SSL errors"),        m_ignoreSslCheckbox);
 
     m_bottomButtonBox = new QDialogButtonBox(this);
     m_bottomButtonBox->addButton(m_connectButton, QDialogButtonBox::AcceptRole);
@@ -142,7 +150,8 @@ void ConnectionDialog::startConnection()
                              m_passwordLineEdit->text(),
                              m_autoconnectCheckbox->isChecked(),
                              m_resourceLineEdit->text().trimmed(),
-                             m_prioritySpinbox->value());
+                             m_prioritySpinbox->value(),
+                             m_ignoreSslCheckbox->isChecked());
 
     this->hide();
 }
