@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@ class ConnectionDialog : public QWidget
 public:
     explicit ConnectionDialog(QString jid, QString password,
                               bool autoconnect, QString resource,
-                              int priority,
+                              int priority, bool ignoreSslErrors,
                               QWidget *parent = nullptr);
     ~ConnectionDialog();
 
@@ -52,7 +52,7 @@ public:
 signals:
     void connectionRequested(QString jid, QString password,
                              bool autoconnect, QString resource,
-                             int priority);
+                             int priority, bool ignoreSslErrors);
 
 
 public slots:
@@ -76,6 +76,8 @@ private:
     QLineEdit *m_resourceLineEdit;
     QSpinBox *m_prioritySpinbox;
 
+    QCheckBox *m_ignoreSslCheckbox;
+
     QPushButton *m_connectButton;
     QPushButton *m_cancelButton;
     QAction *m_cancelAction;
