@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ ContactsModule::ContactsModule(GlobalObject *globalObject,
     connect(m_xmppClient, &QXmppClient::disconnected,
             this, &ContactsModule::onServerDisconnected);
 
-    m_rosterManager = &m_xmppClient->rosterManager();
+    m_rosterManager = m_xmppClient->findExtension<QXmppRosterManager>();
     connect(m_rosterManager, &QXmppRosterManager::rosterReceived,
             this, &ContactsModule::onRosterReceived);
     connect(m_rosterManager, &QXmppRosterManager::presenceChanged,
