@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -45,13 +45,13 @@ int main(int argc, char *argv[])
 {
     QApplication akariApp(argc, argv);
     akariApp.setApplicationName(QStringLiteral("AkariXB"));
-    akariApp.setApplicationVersion(QStringLiteral("0.8"));
+    akariApp.setApplicationVersion(QStringLiteral("0.9"));
     akariApp.setOrganizationName(QStringLiteral("JanCoding"));
     akariApp.setOrganizationDomain(QStringLiteral("jancoding.wordpress.com"));
     // This is mainly needed for window managers under Wayland
     akariApp.setDesktopFileName(QStringLiteral("org.nongnu.akarixb.desktop"));
 
-    std::cout << QString("AkariXB v%1 - JanKusanagi 2015-2019\n"
+    std::cout << QString("AkariXB v%1 - JanKusanagi 2015-2022\n"
                          "https://jancoding.wordpress.com/akarixb\n\n")
                  .arg(akariApp.applicationVersion())
                  .toStdString();
@@ -64,11 +64,11 @@ int main(int argc, char *argv[])
      * timestamps and this way make the builds reproducible.
      *
      */
-    #ifndef REPRODUCIBLEBUILD
+#ifndef REPRODUCIBLEBUILD
     std::cout << QString(" on %1, %2")
                  .arg(__DATE__)
                  .arg(__TIME__).toStdString();
-    #endif
+#endif
     std::cout << "\n";
 
     std::cout << QString("- Running with Qt v%1\n").arg(qVersion())
@@ -82,8 +82,7 @@ int main(int argc, char *argv[])
 
 
     //// Parse command line parameters
-    QStringList cmdLine = qApp->arguments();
-    cmdLine.removeFirst(); // Remove the program executable name/path
+    const QStringList cmdLine = qApp->arguments();
 
     bool debugMode = false;
     bool xmppDebugging = false;
@@ -91,8 +90,10 @@ int main(int argc, char *argv[])
 
     if (!cmdLine.isEmpty())
     {
-        foreach (const QString argument, cmdLine)
-        {
+        for (int param = 1; param < cmdLine.length(); ++param) // Skipping first param,
+        {                                                      // program executable/path
+            const QString argument = cmdLine.at(param);
+
             // Help
             if (argument.startsWith("--help", Qt::CaseInsensitive)
                 || argument.startsWith("-h", Qt::CaseInsensitive))
@@ -137,16 +138,28 @@ int main(int argc, char *argv[])
                 || argument.startsWith("-c", Qt::CaseInsensitive))
             {
                 nextParameterIsConfig = true;
-                cmdLine.removeAll(argument);
             }
             else if (nextParameterIsConfig)
             {
-                const QString configName = "AkariXB_" + argument.toLower();
-                akariApp.setApplicationName(configName);
-                nextParameterIsConfig = false;
+                if (!argument.startsWith("-"))
+                {
+                    const QString configName = "AkariXB_" + argument.toLower();
+                    akariApp.setApplicationName(configName);
+                    nextParameterIsConfig = false;
+
+                    std::cout << "Using alternate config file: "
+                              << configName.toStdString() << "\n";
+                }
+                else
+                {
+                    std::cout << "Error: Alternate config name can't start "
+                                 "with a dash: "
+                              << argument.toStdString()
+                              << "\n\n";
+
+                    return 0;
+                }
 
-                std::cout << "Using alternate config file: "
-                          << configName.toStdString() << "\n";
             }
 
             // Debug mode
@@ -154,7 +167,6 @@ int main(int argc, char *argv[])
                 || argument.startsWith("-d", Qt::CaseInsensitive))
             {
                 debugMode = true;
-                cmdLine.removeAll(argument);
 
                 std::cout << "Debug messages enabled\n";
             }
@@ -164,23 +176,22 @@ int main(int argc, char *argv[])
                 || argument.startsWith("-x", Qt::CaseInsensitive))
             {
                 xmppDebugging = true;
-                cmdLine.removeAll(argument);
                 std::cout << "XMPP debugging enabled\n";
             }
 
-        } // End foreach
+        } // End ranged for
     }
 
 
     // Register custom message handler, to hide debug messages unless specified
     if (!debugMode)
     {
+        std::cout << "To see debug messages while running, use --debug\n";
+
 #ifdef Q_OS_WIN
         FreeConsole();
 #endif
 
-        std::cout << "To see debug messages while running, use --debug\n";
-
         qInstallMessageHandler(customMessageHandler);
     }
 
