@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -23,9 +23,8 @@
 
 MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 {
-    this->setWindowTitle("AkariXB");
+    this->setWindowTitle(QStringLiteral("AkariXB"));
     this->setWindowIcon(QIcon(":/icon/64x64/akarixb.png"));
-    this->setMinimumSize(500, 400);
 
     // Ensure closing a dialog while the main window is hidden, won't end the program
     qApp->setQuitOnLastWindowClosed(false);
@@ -126,7 +125,6 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     m_categoriesList->setFlow(QListView::TopToBottom);
     m_categoriesList->setWrapping(false);
     m_categoriesList->setIconSize(QSize(48, 48));
-    m_categoriesList->setMinimumWidth(120); // TMP/FIXME -- Move to QSplitter
     m_categoriesList->setWordWrap(true);
     m_categoriesList->setMovement(QListView::Static);
     m_categoriesList->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
@@ -183,13 +181,14 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     connect(m_globalObject, &GlobalObject::conversationTabRequested,
             this, &MainWindow::focusChatsModule);
 
-    m_mainLayout = new QHBoxLayout();
-    m_mainLayout->addWidget(m_categoriesList, 1);
-    m_mainLayout->addWidget(m_stackedWidget,  5);
 
-    m_mainWidget = new QWidget(this);
-    m_mainWidget->setLayout(m_mainLayout);
-    this->setCentralWidget(m_mainWidget);
+    m_mainSplitter = new QSplitter(Qt::Horizontal, this);
+    m_mainSplitter->setChildrenCollapsible(false);
+    m_mainSplitter->setContentsMargins(0, 0, 0, 0);
+    m_mainSplitter->setHandleWidth(m_mainSplitter->handleWidth() + 2);
+    m_mainSplitter->addWidget(m_categoriesList);
+    m_mainSplitter->addWidget(m_stackedWidget);
+    this->setCentralWidget(m_mainSplitter);
 
 
     loadSettings();
@@ -200,6 +199,7 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
                                               m_userAutoconnect,
                                               m_userResource,
                                               m_userPriority,
+                                              m_ignoreSslErrors,
                                               this);
     connect(m_connectionDialog, &ConnectionDialog::connectionRequested,
             this, &MainWindow::connectToServer);
@@ -506,8 +506,9 @@ void MainWindow::createDataDir()
 void MainWindow::setupXmppClient()
 {
     m_xmppClient = new QXmppClient(this);
-    m_xmppClient->versionManager().setClientName(QStringLiteral("AkariXB"));
-    m_xmppClient->versionManager().setClientOs("Akari-GNU-OS"); // tmp FIXME xD
+    m_versionManager = m_xmppClient->findExtension<QXmppVersionManager>();
+    m_versionManager->setClientName(QStringLiteral("AkariXB"));
+    m_versionManager->setClientOs("Akari-GNU-OS"); // tmp FIXME xD
     m_disconnectedManually = false;
 
     connect(m_xmppClient, &QXmppClient::connected,
@@ -525,7 +526,7 @@ void MainWindow::setupXmppClient()
     connect(m_xmppClient, &QXmppClient::error,
             this, &MainWindow::onNetworkError);
 
-    connect(&m_xmppClient->versionManager(), &QXmppVersionManager::versionReceived,
+    connect(m_versionManager, &QXmppVersionManager::versionReceived,
             this, &MainWindow::processVersionIq);
 
     m_mucManager = new QXmppMucManager();
@@ -535,11 +536,14 @@ void MainWindow::setupXmppClient()
     m_xmppClient->addExtension(m_receiptManager);
 
     m_discoveryManager = new QXmppDiscoveryManager();
-    m_discoveryManager->setClientName(QStringLiteral("AkariXB ")
+    m_discoveryManager->setClientName(QStringLiteral("AkariXB v")
                                       + qApp->applicationVersion());
     m_discoveryManager->setClientCapabilitiesNode("http://akarixb.nongnu.org");
+    //m_discoveryManager->setClientCategory("client"); // Future tests
+    //m_discoveryManager->setClientType("bot");
     m_xmppClient->addExtension(m_discoveryManager);
 
+
     m_globalObject->setXmppClient(m_xmppClient);
     m_globalObject->setMucManager(m_mucManager);
 }
@@ -556,25 +560,35 @@ void MainWindow::enableXmppDebug()
 void MainWindow::loadSettings()
 {
     QSettings settings;
-    settings.beginGroup("Connection");
-    m_userJid = settings.value("jid").toString();
-    m_userPassword = QByteArray::fromBase64(settings.value("password")
+    settings.beginGroup(QStringLiteral("Connection"));
+    m_userJid = settings.value(QStringLiteral("jid")).toString();
+    m_userPassword = QByteArray::fromBase64(settings.value(QStringLiteral("password"))
                                                     .toByteArray());
-    m_userAutoconnect = settings.value("autoconnect").toBool();
-    m_userResource = settings.value("resource", QStringLiteral("AkariXB"))
+    m_userAutoconnect = settings.value(QStringLiteral("autoconnect"), false).toBool();
+    m_userResource = settings.value(QStringLiteral("resource"), QStringLiteral("AkariXB"))
                              .toString();
-    m_userPriority = settings.value("priority", 10).toInt();
+    m_userPriority = settings.value(QStringLiteral("priority"), 10).toInt();
+    m_ignoreSslErrors = settings.value(QStringLiteral("ignoresslerrors"), false).toBool();
     settings.endGroup();
 
 
-    settings.beginGroup("MainWindow");
-    this->resize(settings.value("windowSize",
+    settings.beginGroup(QStringLiteral("MainWindow"));
+    this->resize(settings.value(QStringLiteral("windowSize"),
                                 QSize(800, 600)).toSize());
 
-    if (settings.contains("windowPosition"))
+    if (settings.contains(QStringLiteral("windowPosition")))
     {
-        this->move(settings.value("windowPosition").toPoint());
+        this->move(settings.value(QStringLiteral("windowPosition")).toPoint());
     }
+
+    if (settings.contains(QStringLiteral("mainSplitterState")))
+    {
+        m_mainSplitter->restoreState(settings.value(QStringLiteral("mainSplitterState"))
+                                             .toByteArray());
+        // Set childrenCollapsible to false AFTER loading state, to ensure
+        m_mainSplitter->setChildrenCollapsible(false); // state does not mess with it
+    }
+
     settings.endGroup();
 }
 
@@ -583,17 +597,19 @@ void MainWindow::saveSettings()
 {
     QSettings settings;
     settings.beginGroup("Connection");
-    settings.setValue("jid",         m_userJid);
-    settings.setValue("password",    m_userPassword.toLocal8Bit().toBase64());
-    settings.setValue("autoconnect", m_userAutoconnect);
-    settings.setValue("resource",    m_userResource);
-    settings.setValue("priority",    m_userPriority);
+    settings.setValue("jid",             m_userJid);
+    settings.setValue("password",        m_userPassword.toLocal8Bit().toBase64());
+    settings.setValue("autoconnect",     m_userAutoconnect);
+    settings.setValue("resource",        m_userResource);
+    settings.setValue("priority",        m_userPriority);
+    settings.setValue("ignoresslerrors", m_ignoreSslErrors);
     settings.endGroup();
 
 
     settings.beginGroup("MainWindow");
-    settings.setValue("windowSize",     this->size());
-    settings.setValue("windowPosition", this->pos());
+    settings.setValue("windowSize",        this->size());
+    settings.setValue("windowPosition",    this->pos());
+    settings.setValue("mainSplitterState", m_mainSplitter->saveState());
     settings.endGroup();
     settings.sync();
 }
@@ -609,29 +625,29 @@ void MainWindow::setStatusIconOnline(QXmppPresence::AvailableStatusType statusTy
         switch (statusType)
         {
         case QXmppPresence::Online:
-            iconFile = ":/images/button-online.png";
+            iconFile = QStringLiteral(":/images/button-online.png");
             break;
 
         case QXmppPresence::Away:
-            iconFile = ":/images/button-away.png";
+            iconFile = QStringLiteral(":/images/button-away.png");
             break;
 
         case QXmppPresence::XA:
-            iconFile = ":/images/button-xa.png";
+            iconFile = QStringLiteral(":/images/button-xa.png");
             break;
 
         case QXmppPresence::DND:
-            iconFile = ":/images/button-dnd.png";
+            iconFile = QStringLiteral(":/images/button-dnd.png");
             break;
 
         default:
-            iconFile = ":/images/button-online.png";
+            iconFile = QStringLiteral(":/images/button-online.png");
             break;
         }
     }
     else
     {
-        iconFile = ":/images/button-offline.png";
+        iconFile = QStringLiteral(":/images/button-offline.png");
     }
 
     m_statusBarIconLabel->setPixmap(QPixmap(iconFile).scaled(16, 16));
@@ -647,13 +663,14 @@ void MainWindow::setStatusIconOnline(QXmppPresence::AvailableStatusType statusTy
 
 void MainWindow::connectToServer(QString jid, QString password,
                                  bool autoconnect, QString resource,
-                                 int priority)
+                                 int priority, bool ignoreSslErrors)
 {
     m_userJid = jid;
     m_userPassword = password;
     m_userAutoconnect = autoconnect;
     m_userResource = resource;
     m_userPriority = priority;
+    m_ignoreSslErrors = ignoreSslErrors;
 
     const QString message = tr("Connecting...");
     m_generalModule->setInfoMessage(message);
@@ -670,12 +687,14 @@ void MainWindow::connectToServer(QString jid, QString password,
     clientConfig.setKeepAliveInterval(m_globalObject->getKeepAliveInterval());
     clientConfig.setKeepAliveTimeout(m_globalObject->getKeepAliveTimeout());
     clientConfig.setAutoReconnectionEnabled(false);
-    /*
-     * TODO, FIXME, need option in UI to ignore SSL issues
-     *
-     * clientConfig.setIgnoreSslErrors(true);
-     *
-     */
+    clientConfig.setIgnoreSslErrors(m_ignoreSslErrors);
+    if (m_ignoreSslErrors)
+    {
+        const QString sslWarning = tr("Warning! Ignoring errors in "
+                                      "SSL connection to server.");
+        m_generalModule->setInfoMessage(sslWarning);
+        m_globalObject->addToLog(sslWarning, true, GlobalObject::LogBad);
+    }
 
     m_disconnectedManually = false;
     m_initialConnectionTimer->start();
@@ -690,7 +709,8 @@ void MainWindow::autoConnectToServer()
                           m_userPassword,
                           m_userAutoconnect,
                           m_userResource,
-                          m_userPriority);
+                          m_userPriority,
+                          m_ignoreSslErrors);
 }
 
 
@@ -698,7 +718,7 @@ void MainWindow::autoConnectToServer()
 void MainWindow::onConnected()
 {
     const QString message = tr("%1 connected.").arg(m_userJid);
-    m_generalModule->setInfoMessage(message);
+    m_generalModule->setInfoMessage(message); // FIXME: show "NO SSL" here?
     m_globalObject->addToLog(message, true, GlobalObject::LogGood);
 
     m_initialConnectionTimer->stop();
@@ -732,11 +752,11 @@ void MainWindow::onConnected()
     this->setStatusIconOnline(QXmppPresence::Online, true);
 
     // Request server version information
-    const QStringList jidParts = m_userJid.split("@");
+    const QStringList jidParts = m_userJid.split(QStringLiteral("@"));
     if (!jidParts.isEmpty())
     {
         m_userServer = jidParts.last();
-        m_xmppClient->versionManager().requestVersion(m_userServer);
+        m_versionManager->requestVersion(m_userServer);
     }
 }
 
@@ -754,7 +774,10 @@ void MainWindow::disconnectFromServer()
 void MainWindow::abortConnectionAttempts()
 {
     this->disconnectFromServer();
-    m_globalObject->addToLog(tr("Aborted connection attempt."));
+
+    const QString message = tr("Aborted connection attempt.");
+    m_generalModule->setInfoMessage(message);
+    m_globalObject->addToLog(message, true, GlobalObject::LogBad);
 
     // Enable 'Connect' action here regardless of when onDisconnected() runs,
     // since there's a race condition in some cases
@@ -769,7 +792,7 @@ void MainWindow::onDisconnected()
     const QString message = tr("Disconnected.");
     m_generalModule->setInfoMessage(message);
     m_globalObject->addToLog(message, true, GlobalObject::LogBad);
-    qDebug() << "\n"
+    qDebug() << "\n" << QTime::currentTime().toString() << "\n"
                 "\n=========================================================="
                 "\n======================-DISCONNECTED-======================"
                 "\n=========================================================="
@@ -945,7 +968,7 @@ void MainWindow::processIq(QXmppIq iq)
     qDebug() << QTime::currentTime().toString() << "IQ" << iq.id()
              << iq.from() << ">" << iq.to() << "Type(EGSR):" << iq.type();
 
-    foreach (const QXmppElement iqExt, iq.extensions())
+    for (const QXmppElement iqExt : iq.extensions())
     {
         qDebug() << iqExt.tagName();
     }
@@ -1074,7 +1097,7 @@ void MainWindow::aboutAkariXB()
                        QString("<big><b>AkariXB v%1</b></big>")
                        .arg(qApp->applicationVersion())
                        + "<br />"
-                         "Copyright 2015-2019  JanKusanagi<br />"
+                         "Copyright 2015-2022  JanKusanagi<br />"
                          "<a href=\"https://jancoding.wordpress.com/akarixb\">"
                          "https://jancoding.wordpress.com/akarixb</a><br />"
                          "<br />"
@@ -1176,23 +1199,13 @@ void MainWindow::setTitleAndTrayInfo()
         const QString idToShow = m_userJid.isEmpty()
                                  ? tr("Account is not configured")
                                  : m_userJid + "/" + m_userResource;
-#ifdef Q_OS_UNIX
-        title = "<b>AkariXB</b> - "
-                + currentTabTitle
-                + "<hr>"
-                  "<br>"
-                + idToShow
-                + (m_globalObject->connectedToServer() ?
-                   QString() : offlineString);
-#else
-        // Some OSes don't render HTML in the tray tooltip
-        title = "AkariXB: "
-                "\n\n"
-                + idToShow
-                + (m_globalObject->connectedToServer() ?
-                   QString() : offlineString);
-#endif
 
+        // Can't use HTML in the tray tooltip until Qt starts supporting
+        // the Description field in SNI icons, which can have HTML
+        title = "AkariXB - " + currentTabTitle + "\n"
+                + idToShow
+                + (m_globalObject->connectedToServer() ?
+                   QString() : offlineString);
 
         m_systrayIcon->setToolTip(title);
 
@@ -1222,15 +1235,11 @@ void MainWindow::showNotification(QString title, QString message)
             title.append(QString(" (%1)").arg(m_userJid));
         }
 
+        // This themed icon overload requires Qt 5.9+, but QXMPP already requires it
         m_systrayIcon->showMessage(title,
                                    message,
-#if QT_VERSION < QT_VERSION_CHECK(5, 9, 0)
-                                   QSystemTrayIcon::Information,
-#else
-                                   // This overload requires Qt 5.9+
                                    QIcon::fromTheme("akarixb",
                                                     QIcon::fromTheme("dialog-information")),
-#endif
                                    10000); // 10 secs
     }
 }
