@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -25,10 +25,10 @@
 #include <QApplication>
 #include <QMenuBar>
 #include <QMenu>
+#include <QSplitter>
 #include <QStatusBar>
 #include <QSystemTrayIcon>
 
-#include <QVBoxLayout>
 #include <QListWidget>
 #include <QStackedWidget>
 #include <QLabel>
@@ -105,7 +105,7 @@ public:
 public slots:
     void connectToServer(QString jid, QString password,
                          bool autoconnect, QString resource,
-                         int priority);
+                         int priority, bool ignoreSslErrors);
     void autoConnectToServer();
     void onConnected();
     void disconnectFromServer();
@@ -171,8 +171,7 @@ private:
 
 
     // GUI
-    QWidget *m_mainWidget;
-    QHBoxLayout *m_mainLayout;
+    QSplitter *m_mainSplitter;
     QListWidget *m_categoriesList;
     QStackedWidget *m_stackedWidget;
 
@@ -213,6 +212,7 @@ private:
     QXmppMucManager *m_mucManager;
     QXmppMessageReceiptManager *m_receiptManager;
     QXmppDiscoveryManager *m_discoveryManager;
+    QXmppVersionManager *m_versionManager;
 
 
     QString m_userJid;
@@ -221,6 +221,7 @@ private:
     QString m_userResource;
     int m_userPriority;
     QString m_userServer;
+    bool m_ignoreSslErrors;
 
     bool m_disconnectedManually;
 };
