@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -377,11 +377,11 @@ void StringListWidget::clearList()
 }
 
 
-void StringListWidget::addStringsToList(QStringList stringList)
+void StringListWidget::addStringsToList(const QStringList stringList)
 {
     const int rowCountBefore = m_tableModel->rowCount();
 
-    foreach (const QString string, stringList)
+    for (const QString string : stringList)
     {
         // FIXME? Check duplicates if needed
         m_tableModel->appendRow(new QStandardItem(string));
@@ -418,7 +418,8 @@ QStringList StringListWidget::getStringsFromList()
 
 void StringListWidget::addItemsToList(QVariantMap stringMap)
 {
-    foreach (QString key, stringMap.keys())
+    const QStringList mapKeys = stringMap.keys();
+    for (QString key : mapKeys)
     {
         key = key.trimmed();
 
