@@ -1,6 +1,6 @@
 /*
  *   This file is part of AkariXB
- *   Copyright 2015-2019  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2015-2022  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -73,7 +73,7 @@ public:
     void setHeader();
 
     void clearList();
-    void addStringsToList(QStringList stringList);
+    void addStringsToList(const QStringList stringList);
     QStringList getStringsFromList();
 
     void addItemsToList(QVariantMap stringMap);
