@@ -4,36 +4,36 @@
 <context>
     <name>ActivityHandler</name>
     <message numerus="yes">
-        <location filename="../src/activityhandler.cpp" line="211"/>
+        <location filename="../src/activityhandler.cpp" line="230"/>
         <source>%Ln hour(s)</source>
         <translation type="unfinished">
             <numerusform></numerusform>
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/activityhandler.cpp" line="222"/>
+        <location filename="../src/activityhandler.cpp" line="241"/>
         <source>%Ln minute(s)</source>
         <translation type="unfinished">
             <numerusform></numerusform>
         </translation>
     </message>
     <message>
-        <location filename="../src/activityhandler.cpp" line="235"/>
+        <location filename="../src/activityhandler.cpp" line="254"/>
         <source>Starting activity %1, which will end at %2.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activityhandler.cpp" line="336"/>
+        <location filename="../src/activityhandler.cpp" line="358"/>
         <source>Not sending message to room %1 because I am not currently in it.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activityhandler.cpp" line="381"/>
+        <location filename="../src/activityhandler.cpp" line="403"/>
         <source>Activity ended: %1.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activityhandler.cpp" line="388"/>
+        <location filename="../src/activityhandler.cpp" line="410"/>
         <source>None</source>
         <comment>Regarding an activity</comment>
         <translation type="unfinished"></translation>
@@ -57,174 +57,221 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="102"/>
-        <source>minutes</source>
+        <location filename="../src/activitymodule.cpp" line="98"/>
+        <source>Mon</source>
+        <comment>Monday, shortened if possible</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="105"/>
-        <source>Online</source>
+        <location filename="../src/activitymodule.cpp" line="100"/>
+        <source>Tue</source>
+        <comment>Tuesday, shortened if possible</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/activitymodule.cpp" line="102"/>
+        <source>Wed</source>
+        <comment>Wednesday, shortened if possible</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/activitymodule.cpp" line="104"/>
+        <source>Thu</source>
+        <comment>Thursday, shortened if possible</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/activitymodule.cpp" line="106"/>
-        <source>Free for Chat</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/activitymodule.cpp" line="107"/>
-        <source>Away</source>
+        <source>Fri</source>
+        <comment>Friday, shortened if possible</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/activitymodule.cpp" line="108"/>
+        <source>Sat</source>
+        <comment>Saturday, shortened if possible</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/activitymodule.cpp" line="110"/>
+        <source>Sun</source>
+        <comment>Sunday, shortened if possible</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/activitymodule.cpp" line="117"/>
+        <source>minutes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/activitymodule.cpp" line="120"/>
+        <source>Online</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/activitymodule.cpp" line="121"/>
+        <source>Free for Chat</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/activitymodule.cpp" line="122"/>
+        <source>Away</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/activitymodule.cpp" line="123"/>
         <source>Extended Away</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="109"/>
+        <location filename="../src/activitymodule.cpp" line="124"/>
         <source>Do not Disturb</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="126"/>
+        <location filename="../src/activitymodule.cpp" line="141"/>
         <source>seconds</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="145"/>
+        <location filename="../src/activitymodule.cpp" line="160"/>
         <source>All rooms</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="146"/>
+        <location filename="../src/activitymodule.cpp" line="161"/>
         <source>Several rooms</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="147"/>
+        <location filename="../src/activitymodule.cpp" line="162"/>
         <source>A few rooms</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="162"/>
+        <location filename="../src/activitymodule.cpp" line="177"/>
         <source>List of room or user addresses, separated by space</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="151"/>
+        <location filename="../src/activitymodule.cpp" line="247"/>
+        <source>Days Of The Week</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/activitymodule.cpp" line="166"/>
         <source>Also to active private chats</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="148"/>
+        <location filename="../src/activitymodule.cpp" line="163"/>
         <source>None of the rooms</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="157"/>
+        <location filename="../src/activitymodule.cpp" line="172"/>
         <source>Additional specific JIDs:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="169"/>
+        <location filename="../src/activitymodule.cpp" line="184"/>
         <source>Sa&amp;ve Activity</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="218"/>
+        <location filename="../src/activitymodule.cpp" line="242"/>
         <source>Name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="219"/>
+        <location filename="../src/activitymodule.cpp" line="243"/>
         <source>Maximum Times Per Day</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="220"/>
+        <location filename="../src/activitymodule.cpp" line="244"/>
         <source>Probability</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="221"/>
+        <location filename="../src/activitymodule.cpp" line="245"/>
         <source>Time Range</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="222"/>
+        <location filename="../src/activitymodule.cpp" line="246"/>
         <source>Date Range</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="223"/>
+        <location filename="../src/activitymodule.cpp" line="248"/>
         <source>Duration</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="224"/>
+        <location filename="../src/activitymodule.cpp" line="249"/>
         <source>Set Status Type</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="225"/>
+        <location filename="../src/activitymodule.cpp" line="250"/>
         <source>Status Messages</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="226"/>
+        <location filename="../src/activitymodule.cpp" line="251"/>
         <source>Availability</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="227"/>
+        <location filename="../src/activitymodule.cpp" line="252"/>
         <source>Reaction Time</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="228"/>
+        <location filename="../src/activitymodule.cpp" line="253"/>
         <source>Descriptions</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="229"/>
+        <location filename="../src/activitymodule.cpp" line="254"/>
         <source>Messages Before</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="230"/>
+        <location filename="../src/activitymodule.cpp" line="255"/>
         <source>Messages Afterwards</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="231"/>
+        <location filename="../src/activitymodule.cpp" line="256"/>
         <source>Send Messages To</source>
         <translation type="unfinished"></translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/activitymodule.cpp" line="309"/>
+        <location filename="../src/activitymodule.cpp" line="334"/>
         <source>Loaded %Ln activities.</source>
         <translation type="unfinished">
             <numerusform></numerusform>
         </translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="338"/>
+        <location filename="../src/activitymodule.cpp" line="363"/>
         <source>New Activity</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="473"/>
+        <location filename="../src/activitymodule.cpp" line="514"/>
         <source>Activity exists</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitymodule.cpp" line="474"/>
+        <location filename="../src/activitymodule.cpp" line="515"/>
         <source>Error: There is already an activity in the list with this name.</source>
         <translation type="unfinished"></translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/activitymodule.cpp" line="571"/>
+        <location filename="../src/activitymodule.cpp" line="622"/>
         <source>Saved %Ln activities.</source>
         <translation type="unfinished">
             <numerusform></numerusform>
@@ -351,17 +398,17 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/commandhandler.cpp" line="398"/>
+        <location filename="../src/commandhandler.cpp" line="399"/>
         <source>Started detached program successfully.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/commandhandler.cpp" line="435"/>
+        <location filename="../src/commandhandler.cpp" line="437"/>
         <source>Command gave no output text.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/commandhandler.cpp" line="475"/>
+        <location filename="../src/commandhandler.cpp" line="477"/>
         <source>This command is an alias to itself!</source>
         <translation type="unfinished"></translation>
     </message>
@@ -776,40 +823,55 @@ The reply will be the console output of the program, unless you specify a reply
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/connectiondialog.cpp" line="65"/>
+        <location filename="../src/connectiondialog.cpp" line="62"/>
+        <source>Use carefully.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/connectiondialog.cpp" line="63"/>
+        <source>This allows connecting to servers with bad security certificates.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/connectiondialog.cpp" line="72"/>
         <source>&amp;Connect</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/connectiondialog.cpp" line="75"/>
+        <location filename="../src/connectiondialog.cpp" line="82"/>
         <source>Cancel</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/connectiondialog.cpp" line="89"/>
+        <location filename="../src/connectiondialog.cpp" line="96"/>
         <source>XMPP Address (Jabber ID)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/connectiondialog.cpp" line="90"/>
+        <location filename="../src/connectiondialog.cpp" line="97"/>
         <source>Password</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/connectiondialog.cpp" line="91"/>
+        <location filename="../src/connectiondialog.cpp" line="98"/>
         <source>Connect Automatically</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/connectiondialog.cpp" line="92"/>
+        <location filename="../src/connectiondialog.cpp" line="99"/>
         <source>Resource</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/connectiondialog.cpp" line="93"/>
+        <location filename="../src/connectiondialog.cpp" line="100"/>
         <source>Priority</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../src/connectiondialog.cpp" line="101"/>
+        <source>Ignore SSL errors</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ContactsModule</name>
@@ -958,6 +1020,11 @@ The reply will be the console output of the program, unless you specify a reply
         <source>Rooms:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../src/generalmodule.cpp" line="157"/>
+        <source>Server version: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../src/generalmodule.cpp" line="295"/>
         <source>%1 joined, out of %2 configured</source>
@@ -1175,52 +1242,52 @@ The reply will be the console output of the program, unless you specify a reply
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../src/mainwindow.cpp" line="71"/>
+        <location filename="../src/mainwindow.cpp" line="70"/>
         <source>Settings file in use: %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="134"/>
+        <location filename="../src/mainwindow.cpp" line="132"/>
         <source>General</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="137"/>
+        <location filename="../src/mainwindow.cpp" line="135"/>
         <source>Rooms</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="144"/>
+        <location filename="../src/mainwindow.cpp" line="142"/>
         <source>Contacts</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="147"/>
+        <location filename="../src/mainwindow.cpp" line="145"/>
         <source>Commands</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="150"/>
+        <location filename="../src/mainwindow.cpp" line="148"/>
         <source>Room Speech</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="153"/>
+        <location filename="../src/mainwindow.cpp" line="151"/>
         <source>Conversation</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="156"/>
+        <location filename="../src/mainwindow.cpp" line="154"/>
         <source>Activities</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="159"/>
+        <location filename="../src/mainwindow.cpp" line="157"/>
         <source>Identity</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="162"/>
+        <location filename="../src/mainwindow.cpp" line="160"/>
         <source>Log</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1286,7 +1353,7 @@ The reply will be the console output of the program, unless you specify a reply
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="357"/>
-        <location filename="../src/mainwindow.cpp" line="1073"/>
+        <location filename="../src/mainwindow.cpp" line="1098"/>
         <source>About AkariXB</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1311,162 +1378,167 @@ The reply will be the console output of the program, unless you specify a reply
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="658"/>
+        <location filename="../src/mainwindow.cpp" line="677"/>
         <source>Connecting...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="700"/>
+        <location filename="../src/mainwindow.cpp" line="695"/>
+        <source>Warning! Ignoring errors in SSL connection to server.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="722"/>
         <source>%1 connected.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="757"/>
+        <location filename="../src/mainwindow.cpp" line="780"/>
         <source>Aborted connection attempt.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="769"/>
+        <location filename="../src/mainwindow.cpp" line="794"/>
         <source>Disconnected.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="790"/>
+        <location filename="../src/mainwindow.cpp" line="815"/>
         <source>Disconnected</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="791"/>
+        <location filename="../src/mainwindow.cpp" line="816"/>
         <source>Connection to the server was lost.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="807"/>
+        <location filename="../src/mainwindow.cpp" line="832"/>
         <source>Connection seems stuck. Trying again...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="884"/>
+        <location filename="../src/mainwindow.cpp" line="909"/>
         <source>Presence error %1 from %2: %3</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="901"/>
+        <location filename="../src/mainwindow.cpp" line="926"/>
         <source>%1 wants to subscribe to your presence.</source>
         <comment>%1 is another user&apos;s address</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="909"/>
+        <location filename="../src/mainwindow.cpp" line="934"/>
         <source>%1 accepted your subscription request.</source>
         <comment>%1 is another user&apos;s address</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="917"/>
+        <location filename="../src/mainwindow.cpp" line="942"/>
         <source>%1 unsubscribed from your presence.</source>
         <comment>%1 is another user&apos;s address</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="925"/>
+        <location filename="../src/mainwindow.cpp" line="950"/>
         <source>%1 removed your authorization to see their presence.</source>
         <comment>%1 is another user&apos;s address</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="965"/>
+        <location filename="../src/mainwindow.cpp" line="990"/>
         <source>Received version information from %1:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="988"/>
+        <location filename="../src/mainwindow.cpp" line="1013"/>
         <source>Socket Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="993"/>
+        <location filename="../src/mainwindow.cpp" line="1018"/>
         <source>KeepAlive Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="997"/>
+        <location filename="../src/mainwindow.cpp" line="1022"/>
         <source>XMPP Stream Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1006"/>
+        <location filename="../src/mainwindow.cpp" line="1031"/>
         <source>Network error: %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1018"/>
+        <location filename="../src/mainwindow.cpp" line="1043"/>
         <source>Chats</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1081"/>
+        <location filename="../src/mainwindow.cpp" line="1106"/>
         <source>AkariXB is a Jabber/XMPP bot.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1084"/>
+        <location filename="../src/mainwindow.cpp" line="1109"/>
         <source>You can talk to it, make it join chatrooms, etc.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1088"/>
+        <location filename="../src/mainwindow.cpp" line="1113"/>
         <source>English translation by JanKusanagi.</source>
         <comment>TRANSLATORS: Change this with your language and name. If there was another translator before you, add your name after theirs ;)</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1095"/>
+        <location filename="../src/mainwindow.cpp" line="1120"/>
         <source>Thanks to all the testers, translators and packagers, who help make AkariXB better!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1100"/>
+        <location filename="../src/mainwindow.cpp" line="1125"/>
         <source>AkariXB is Free Software, licensed under the GNU GPL license, and uses some Oxygen icons under LGPL license.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1125"/>
+        <location filename="../src/mainwindow.cpp" line="1150"/>
         <source>Offline</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1177"/>
+        <location filename="../src/mainwindow.cpp" line="1202"/>
         <source>Account is not configured</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1276"/>
+        <location filename="../src/mainwindow.cpp" line="1287"/>
         <source>&amp;Hide Window</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1283"/>
+        <location filename="../src/mainwindow.cpp" line="1294"/>
         <source>&amp;Show Window</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1300"/>
+        <location filename="../src/mainwindow.cpp" line="1311"/>
         <source>Quit?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1301"/>
+        <location filename="../src/mainwindow.cpp" line="1312"/>
         <source>Are you sure?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1303"/>
+        <location filename="../src/mainwindow.cpp" line="1314"/>
         <source>Yes, quit AkariXB</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1303"/>
+        <location filename="../src/mainwindow.cpp" line="1314"/>
         <source>No</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1736,7 +1808,7 @@ The reply will be the console output of the program, unless you specify a reply
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/roomspeaktab.cpp" line="166"/>
+        <location filename="../src/roomspeaktab.cpp" line="174"/>
         <source>Saved %Ln sentence(s) of type %1.</source>
         <translation type="unfinished">
             <numerusform></numerusform>
@@ -1751,12 +1823,12 @@ The reply will be the console output of the program, unless you specify a reply
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/stringlistwidget.cpp" line="658"/>
+        <location filename="../src/stringlistwidget.cpp" line="659"/>
         <source>Enter text</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/stringlistwidget.cpp" line="623"/>
+        <location filename="../src/stringlistwidget.cpp" line="624"/>
         <source>Item text is not valid</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1766,12 +1838,12 @@ The reply will be the console output of the program, unless you specify a reply
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/stringlistwidget.cpp" line="659"/>
+        <location filename="../src/stringlistwidget.cpp" line="660"/>
         <source>Enter a new line of text for the list</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/stringlistwidget.cpp" line="513"/>
+        <location filename="../src/stringlistwidget.cpp" line="514"/>
         <source>The item already exists</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1811,27 +1883,27 @@ The reply will be the console output of the program, unless you specify a reply
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/stringlistwidget.cpp" line="515"/>
+        <location filename="../src/stringlistwidget.cpp" line="516"/>
         <source>Error: There is already an item in the list with the text %1, and this list does not allow duplicates.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/stringlistwidget.cpp" line="636"/>
+        <location filename="../src/stringlistwidget.cpp" line="637"/>
         <source>Regular expression is not valid</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/stringlistwidget.cpp" line="638"/>
+        <location filename="../src/stringlistwidget.cpp" line="639"/>
         <source>Syntax error at position %1:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/stringlistwidget.cpp" line="705"/>
+        <location filename="../src/stringlistwidget.cpp" line="706"/>
         <source>Modify text</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/stringlistwidget.cpp" line="706"/>
+        <location filename="../src/stringlistwidget.cpp" line="707"/>
         <source>Update the text for this item</source>
         <translation type="unfinished"></translation>
     </message>
