@@ -191,6 +191,45 @@
         <source>Additional specific JIDs:</source>
         <translation>JIDs específics adicionals:</translation>
     </message>
+    <message>
+        <source>Mon</source>
+        <comment>Monday, shortened if possible</comment>
+        <translation>Dl</translation>
+    </message>
+    <message>
+        <source>Tue</source>
+        <comment>Tuesday, shortened if possible</comment>
+        <translation type="unfinished">Dt</translation>
+    </message>
+    <message>
+        <source>Wed</source>
+        <comment>Wednesday, shortened if possible</comment>
+        <translation type="unfinished">Dc</translation>
+    </message>
+    <message>
+        <source>Thu</source>
+        <comment>Thursday, shortened if possible</comment>
+        <translation>Dj</translation>
+    </message>
+    <message>
+        <source>Fri</source>
+        <comment>Friday, shortened if possible</comment>
+        <translation>Dv</translation>
+    </message>
+    <message>
+        <source>Sat</source>
+        <comment>Saturday, shortened if possible</comment>
+        <translation>Ds</translation>
+    </message>
+    <message>
+        <source>Sun</source>
+        <comment>Sunday, shortened if possible</comment>
+        <translation>Dg</translation>
+    </message>
+    <message>
+        <source>Days Of The Week</source>
+        <translation>Dies de la setmana</translation>
+    </message>
 </context>
 <context>
     <name>ChatModule</name>
@@ -523,10 +562,6 @@ La resposta serà la sortida per consola del programa, llevat que especifiquis u
         <source>Explanation shown to users with the %1 command</source>
         <translation>Explicació que es mostrarà als usuaris amb la ordre %1</translation>
     </message>
-    <message>
-        <source>The name, without the prefix or any spaces</source>
-        <translation type="vanished">El nom, sense el prefix o espais</translation>
-    </message>
     <message>
         <source>The command name can&apos;t contain spaces.</source>
         <translation>El nom de la ordre no pot tenir espais.</translation>
@@ -671,6 +706,18 @@ La resposta serà la sortida per consola del programa, llevat que especifiquis u
         <source>&amp;Connect</source>
         <translation>&amp;Connectar</translation>
     </message>
+    <message>
+        <source>Use carefully.</source>
+        <translation type="unfinished">Utilitzar amb compte.</translation>
+    </message>
+    <message>
+        <source>This allows connecting to servers with bad security certificates.</source>
+        <translation>Això permet connectar a servidors amb certificats de seguretat incorrectes.</translation>
+    </message>
+    <message>
+        <source>Ignore SSL errors</source>
+        <translation>Ignorar errors SSL</translation>
+    </message>
 </context>
 <context>
     <name>ContactsModule</name>
@@ -799,6 +846,10 @@ La resposta serà la sortida per consola del programa, llevat que especifiquis u
         <translatorcomment>Meh...</translatorcomment>
         <translation>S&apos;ha entrat a %1, de %2 configurades</translation>
     </message>
+    <message>
+        <source>Server version: %1</source>
+        <translation>Versió del servidor: %1</translation>
+    </message>
 </context>
 <context>
     <name>HelpWidget</name>
@@ -1211,6 +1262,10 @@ La resposta serà la sortida per consola del programa, llevat que especifiquis u
         <source>Received version information from %1:</source>
         <translation>S&apos;ha rebut la informació de versió de %1:</translation>
     </message>
+    <message>
+        <source>Warning! Ignoring errors in SSL connection to server.</source>
+        <translation type="unfinished">¡Avís! Ignorant errors a la connexió SSL al servidor.</translation>
+    </message>
 </context>
 <context>
     <name>MessageHandler</name>
@@ -1352,11 +1407,6 @@ La resposta serà la sortida per consola del programa, llevat que especifiquis u
         <source>Greet people</source>
         <translation>Saludar a gent</translation>
     </message>
-    <message>
-        <source>Speak casually</source>
-        <translatorcomment>Meh...</translatorcomment>
-        <translation type="obsolete">Parlar de forma casual</translation>
-    </message>
     <message>
         <source>Converse</source>
         <translation>Conversar</translation>
@@ -1418,7 +1468,7 @@ La resposta serà la sortida per consola del programa, llevat que especifiquis u
     </message>
     <message>
         <source>Regular expressions to be matched against messages coming from the chatrooms, and possible messages to send in response.</source>
-        <translation type="unfinished">Expressions regulars amb les que comparar els missatges provinents de les sales de xat, i possibles missatges per enviar en resposta.</translation>
+        <translation>Expressions regulars amb les que comparar els missatges provinents de les sales de xat, i possibles missatges per enviar en resposta.</translation>
     </message>
 </context>
 <context>
@@ -1521,7 +1571,7 @@ La resposta serà la sortida per consola del programa, llevat que especifiquis u
     <name>VariableParser</name>
     <message>
         <source>Unbalanced braces: %1 opening and %2 closing</source>
-        <translation type="unfinished">Claus descompensades: %1 que obren i %2 que tanquen</translation>
+        <translation>Claus descompensades: %1 que obren i %2 que tanquen</translation>
     </message>
     <message>
         <source>This substitution is unknown, or not valid in this context: %1</source>
